For best practices, you should read the DEVELOPER.RULES file which comes with the standard pyjamas distribution. The web site is itself a pyjamas application, so the DEVELOPER.RULES even apply to contributions to the web site.

If you just want to submit a single modification, submit it as a patch, in diff format, at the pyjamas bugtracker and then it is best to join the mailing list, pyjamas-dev, and let people know. You should ideally use git diff or git-am. `(Note: if you are a Windows user, go and get git-win32: there is no excuse for not using the best tools for the job!)`

However, if you want to regularly submit patches, just ask on pyjamas-dev and you will be given an account, simple as that. You will be expected to follow, at all times, the DEVELOPER.RULES, which are really quite straightforward and are there to give you the freedom to do whatever you like, as long as it doesn't inconvenience anyone else (users or developers).